@@ -4,3 +4,6 @@ from .stack import Stack
 from .queue import Queue
 from .linkedlist import SinglyLinkedList
 from .doublylinkedlist import DoublyLinkedList
+from .circularList import CircularList
+from .binarySearchTree import BST
+from .dequeue import DeQueue
