@@ -1,3 +1,11 @@
+"""Trie, also called digital tree or prefix tree, is a kind of search tree—an ordered tree data structure used to store a dynamic set or associative array where the keys are usually strings."""
+
+from typing import TypeVar
+
+
+T = TypeVar("T")
+
+
 class Trie:
     # Static variables
     wordcount = 0
@@ -6,21 +14,17 @@ class Trie:
         self.__root = {}
         self.__end = ""
 
-    def build(self, array):
-        """Builds a trie structure given array of words
+    def build(self, array: list) -> None:
+
+        """Builds a trie structure given array of words"""
 
-        Args:
-            array ([string]): array of words
-        """
         for el in array:
             self.add(el)
 
-    def add(self, string):
-        """Add word to the trie structure
+    def add(self, string: str) -> None:
+
+        """Add word to the trie structure"""
 
-        Args:
-            string (string): add word to the trie structure
-        """
         self.wordcount += 1
         node = self.__root
         for i in range(len(string)):
@@ -30,15 +34,9 @@ class Trie:
             node = node[char]
         node[self.__end] = "*"
 
-    def contains(self, string):
-        """Checks if a trie contains a word or substring of word
+    def contains(self, string: str) -> bool:
 
-        Args:
-            string (string): word to be searched
-
-        Returns:
-            boolean: True if word present else False
-        """
+        """Checks if a trie contains a word or substring of word"""
 
         node = self.__root
         for i in range(len(string)):
